#!/bin/sh

#
# Copyright (c) 2009 Sun Microsystems, Inc.  All rights reserved.
# $COPYRIGHT$
#
# Additional copyrights may follow
#
# $HEADER$
#

#
# Wrapper script around the binary Open MPI ompi_info utility 
# for calling the appropriate ompi_info-(32|64) script
#

# Change into the $topdir/bin directory
dirname=`dirname $0`
uname_m=`uname -m`

# If a rel path was given, make dirname an abs path
echo $0 | egrep '^\.\.' > /dev/null
if test "$?" = "0"; then
    dirname="`pwd`/$dirname"
fi
cd $dirname

# We need to set LD_LIBRARY_PATH here because the hardcoded
# rpath for 64-bit objects is $ORIGIN
LD_LIBRARY_PATH="$dirname:$dirname/../lib/64:$LD_LIBRARY_PATH"
export LD_LIBRARY_PATH

if test "$*" = "-h" -o "$*" = "--help"; then
    cat <<EOT
Usage: $0 [-m32|-m64]
 -m32       - Display Open MPI information for 32-bit
 -m64       - Display Open MPI information for 64-bit
 -h|--help  - This help menu
EOT
    exit
fi

# Setup bitness-specific ompi_info's
if test -f "$dirname/32/ompi_info.bin"; then
    ompi_info_32="$dirname/32/ompi_info.bin"
else
    ompi_info_32="$dirname/ompi_info"
fi
if test -f "$dirname/64/ompi_info.bin"; then
    ompi_info_64="$dirname/64/ompi_info.bin"
else
    ompi_info_64="$dirname/ompi_info"
fi

# Shell functions for calling bitness-specific ompi_info
do_32_bit() {
    echo "Displaying Open MPI information for 32-bit ..."
    $ompi_info_32 $@
}
do_64_bit() {
    echo "Displaying Open MPI information for 64-bit ..."
    $ompi_info_64 $@
}

# Default to 32-bit or 64-bit, based on the system architecture
echo $uname_m | grep 64 >/dev/null 
if test "$?" = "0"; then
    _64_bit_mode=1
else
    _32_bit_mode=1
fi

ompi_info_args="$*"
echo $* | egrep '\-m32' >/dev/null
if test "$?" = "0"; then
    ompi_info_args=`echo $* | sed 's/-m32//'`
    _32_bit_mode=1
    _64_bit_mode=0
fi

echo $* | egrep '\-m64' >/dev/null
if test "$?" = "0"; then
    ompi_info_args=`echo $* | sed 's/-m64//'`
    _64_bit_mode=1
    _32_bit_mode=0
fi

# Run the bitness-specific ompi_info based on the following 
# (default to 64-bit):
#   1. -m flag 
#   2. system architecture
if test "$_32_bit_mode" = 1; then
    do_32_bit $ompi_info_args
elif test "$_64_bit_mode" = "1"; then
    do_64_bit $ompi_info_args
else
    do_64_bit $ompi_info_args
fi
